==> wxPostgres-0.2.1.tar.gz: wxPostgres/wxPg/binding/grid_binding.h <==
/* grid_binding.h - binding wxGrid to display the values of some
    fields in wxPg::Result_data

    Copyright (C) 2008, 2009 Aurimas Černius

    This file is part of wxPostgres.

    wxPostgres is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    wxPostgres is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with wxPostgres.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __GRID_BINDING_H
#define __GRID_BINDING_H

#include "wxPg/conf.h"
#include "wxPg/binding/binding.h"
#include "wxPg/db/result_data_provider.h"
#include<wx/grid.h>
#include<map>

namespace wxPg{

/** Binding wxGrid to display data from wxPg::Result_data_provider. */
class wxPG_DECLSPEC
Grid_binding : public Binding{
public:
    /** Creates new object.
        Call grid() and data() to complete initialization.
    */
    Grid_binding();

    /** Creates new object and binds grid to it.
        Call data() to complete initialization.
        @param grid - grid to bind.
    */
    explicit
    Grid_binding(wxGrid *grid);

    /** Create new object with data as source.
        Call grid() to complete initialization.
        @param data - query result to display in grid.
    */
    explicit
    Grid_binding(Result_data_provider *data);

    /** Create new object and initialize it with grid and data.
        @param grid - grid to bind.
        @param data - query result to display in grid.
    */
    Grid_binding(wxGrid *grid, Result_data_provider *data);

    /** Destroy object. */
    virtual
    ~Grid_binding(){}

    /** Set grid in wich data will be displayed.
        @param grid - grid to bind.
    */
    void
    grid(wxGrid *grid){this->grid_ = grid;}

    /** Return currenly binded grid.
        @return currenly binded grid.
    */
    wxGrid*
    grid(){return this->grid_;}

    /** Set data to be displayed in grid.
        @param data - query result to display in grid.
    */
    void
    data(Result_data_provider *data){this->data_ = data;}

    /** Return data, currently used by this object.
        @return data, currently used by this object.
    */
    Result_data_provider*
    data(){return this->data_;}

    /** Bind grid column to database field. Actual update occurs
        when update_UI() is called.
        @param col_idx - grid columns index. If grid does not have column
        with index col_idx, enouth columns will be created,
        when update_UI() is called.
        @param field - database field. Grid column will contain values from
        this field.
    */
    void
    bind(int col_idx, const wxString &field);

    /** Bind next grid column to database field.
        The newly binded column has index, that is bigger by 1
        than currenly binded column with highest index.
        It's not recomended to mix this method with other binding methods.
        Actual update occurs when update_UI() is called.
    */
    void
    bind(const wxString &field);

    /** Bind grid columns to database fields.
        Actual update occurs when update_UI() is called.
        @param col_bindings - keys are column indices, values are database
        fields binded to them.
    */
    void
    bind(const std::map<int, wxString> &col_bindings){
        this->col_bindings_ = col_bindings;
    }

    /** Return current bindings for grid.
        Keys in map are column indices, values are database
        fields binded to them.
        @return current bindings.
    */
    const std::map<int, wxString>&
    bindings()const{return this->col_bindings_;}

    /** Remove column from current bindings.
        Actual update occurs when update_UI() is called.
        @param col_idx - grid column index.
    */
    void
    unbind(int col_idx){this->col_bindings_.erase(col_idx);}

    /** Remove all binded columns from list.
        Actual update occurs when update_UI() is called.
    */
    void
    unbind(){this->col_bindings_.clear();}

    /** Set label for grid column, binded to database field.
        For columns, that don't have specified labels, field name is
        used instead.
        If no field is binded to column, label of that column is not changed.
        Labels are assigned when update_UI() is called.
        @param field - database field. Grid column, that is binded to this
        field will have specified label.
        @param label - label for column.
    */
    void
    col_label(const wxString &field, const wxString &label){
        this->col_labels_[field] = label;
    }

    /** Remove assigned label from column, displaying values of database field.
        Labels are assigned when update_UI() is called.
        @param field - database field.
    */
    void
    rem_col_label(const wxString &field){this->col_labels_.erase(field);}

    /** Set labels for grid columns.
        Labels are assigned when update_UI() is called.
        @param labels - keys are fied names, values are labels for
        grid columns.
    */
    void
    col_labels(const std::map<wxString, wxString> &labels){
        this->col_labels_ = labels;
    }

    /** Returns currently specified labels for fields.
        Keys in map are fied names, values are labels.
        @return current column labels.
    */
    std::map<wxString, wxString>&
    col_labels(){return this->col_labels_;}

    /** Clears all specified labels for grid columns.
        Labels are assigned when update_UI() is called.
    */
    void
    col_labels_clear(){this->col_labels_.clear();}

    /** Update binded grid.
        If there are binded columns, columns are created or deleted in grid,
        so that last column in grid woud have index, equal to highest binded
        index. Binded columns will be filled with data from from result data,
        grid will contain as much rows as there are them in result data.\n
        Columns, that have no binding are unchanged.\n
        If there are no binded columns, grid will display entire result data,
        columns and rows will be created or deleted to match those of result
        data.\n
        Column labels are set to specified labels for field, or to field names,
        if there are no specied labels for some of fields.
    */
    virtual void
    update_UI();
protected:
    wxGrid*
    grid_;

    Result_data_provider*
    data_;

    std::map<int, wxString>
    col_bindings_;

    std::map<wxString, wxString>
    col_labels_;
private:
    Grid_binding(const Grid_binding&){}
    Grid_binding &operator=(const Grid_binding&){return *this;}

    inline void
    prepare_grid_();

    inline const wxString
    col_label_(const wxString&);

    inline void
    fill_row_(int row);

    inline void
    fill_row_all_(int row);

    // Does nothing. Inherited only.
    virtual void
    unbind(wxWindow *c);
};

}

#endif

==> wxPostgres-0.3.1.tar.gz: wxPostgres/wxPg/binding/grid_binding.h <==
/* grid_binding.h - binding wxGrid to display the values of some
    fields in wxPg::Result_data

    Copyright (C) 2008, 2009 Aurimas Černius

    This file is part of wxPostgres.

    wxPostgres is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    wxPostgres is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with wxPostgres.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __GRID_BINDING_H
#define __GRID_BINDING_H

#include "wxPg/conf.h"
#include "wxPg/binding/binding.h"
#include "wxPg/db/result_data_provider.h"
#include "wxPg/binding/grid_bind_def.h"
#include<wx/grid.h>


namespace wxPg{

/** Binding wxGrid to display data from wxPg::Result_data_provider. */
class wxPG_DECLSPEC
Grid_binding : public Binding{
public:
    /** Creates new object.
        Call grid() and data() to complete initialization.
    */
    Grid_binding();

    /** Creates new object and binds grid to it.
        Call data() to complete initialization.
        @param grid - grid to bind.
    */
    explicit
    Grid_binding(wxGrid *grid);

    /** Create new object with data as source.
        Call grid() to complete initialization.
        @param data - query result to display in grid.
    */
    explicit
    Grid_binding(Result_data_provider *data);

    /** Create new object and initialize it with grid and data.
        @param grid - grid to bind.
        @param data - query result to display in grid.
    */
    Grid_binding(wxGrid *grid, Result_data_provider *data);

    /** Destroy object. */
    virtual
    ~Grid_binding();

    /** Set grid in wich data will be displayed.
        @param grid - grid to bind.
    */
    void
    grid(wxGrid *grid){this->grid_ = grid;}

    /** Return currenly binded grid.
        @return currenly binded grid.
    */
    wxGrid*
    grid(){return this->grid_;}

    /** Set data to be displayed in grid.
        @param data - query result to display in grid.
    */
    void
    data(Result_data_provider *data){this->data_ = data;}

    /** Return data, currently used by this object.
        @return data, currently used by this object.
    */
    Result_data_provider*
    data(){return this->data_;}

    /** Set binding definitions to be used.
        It is optional to set them. If not set, will be created automatically.
        @param bind_defs - binding definitions to be used by this object.
        @param delete_defs - shoud this object delete definitions.
    */
    void
    bind_defs(Grid_bind_def *bind_defs, bool delete_defs = true);

    /** Return current binding definitions. */
    Grid_bind_def*
    bind_defs(){return this->bind_defs_;}

    /** Bind grid column to database field. Actual update occurs
        when update_UI() is called.
        @param col_idx - grid columns index. If grid does not have column
        with index col_idx, enouth columns will be created,
        when update_UI() is called.
        @param field - database field. Grid column will contain values from
        this field.
    */
    void
    bind(int col_idx, const wxString &field);

    /** Bind next grid column to database field.
        The newly binded column has index, that is bigger by 1
        than currenly binded column with highest index.
        It's not recomended to mix this method with other binding methods.
        Actual update occurs when update_UI() is called.
    */
    void
    bind(const wxString &field);

    /** Bind grid columns to database fields.
        Actual update occurs when update_UI() is called.
        @param col_bindings - keys are column indices, values are database
        fields binded to them.
    */
    void
    bind(const std::map<int, wxString> &col_bindings);

    /** Return current bindings for grid.
        Keys in map are column indices, values are database
        fields binded to them.
        @return current bindings.
    */
    const std::map<int, wxString>&
    bindings();

    /** Remove column from current bindings.
        Actual update occurs when update_UI() is called.
        @param col_idx - grid column index.
    */
    void
    unbind(int col_idx);

    /** Remove all binded columns from list.
        Actual update occurs when update_UI() is called.
    */
    void
    unbind();

    /** Set label for grid column, binded to database field.
        For columns, that don't have specified labels, field name is
        used instead.
        If no field is binded to column, label of that column is not changed.
        Labels are assigned when update_UI() is called.
        @param field - database field. Grid column, that is binded to this
        field will have specified label.
        @param label - label for column.
    */
    void
    col_label(const wxString &field, const wxString &label);

    /** Remove assigned label from column, displaying values of database field.
        Labels are assigned when update_UI() is called.
        @param field - database field.
    */
    void
    rem_col_label(const wxString &field);

    /** Set labels for grid columns.
        Labels are assigned when update_UI() is called.
        @param labels - keys are fied names, values are labels for
        grid columns.
    */
    void
    col_labels(const std::map<wxString, wxString> &labels);

    /** Returns currently specified labels for fields.
        Keys in map are fied names, values are labels.
        @return current column labels.
    */
    const std::map<wxString, wxString>&
    col_labels();

    /** Clears all specified labels for grid columns.
        Labels are assigned when update_UI() is called.
    */
    void
    col_labels_clear();

    /** Update binded grid.
        If there are binded columns, columns are created or deleted in grid,
        so that last column in grid woud have index, equal to highest binded
        index. Binded columns will be filled with data from from result data,
        grid will contain as much rows as there are them in result data.\n
        Columns, that have no binding are unchanged.\n
        If there are no binded columns, grid will display entire result data,
        columns and rows will be created or deleted to match those of result
        data.\n
        Column labels are set to specified labels for field, or to field names,
        if there are no specied labels for some of fields.
    */
    virtual void
    update_UI();
protected:
    wxGrid*
    grid_;

    Result_data_provider*
    data_;
private:
    Grid_binding(const Grid_binding&){}
    Grid_binding &operator=(const Grid_binding&){return *this;}

    inline void
    prepare_grid_();

    inline void
    fill_row_(int row);

    inline void
    fill_row_all_(int row);

    inline void
    make_bind_defs_();

    // Does nothing. Inherited only.
    virtual void
    unbind(wxWindow *c);

    Grid_bind_def*
    bind_defs_;

    bool
    delete_defs_;
};

}

#endif
